@@ -5,13 +5,14 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.15';
+our $VERSION = '0.16';
 
 use base qw/Import::Export/;
 
 our %EX = (
         const => [qw/all/],
 	make_readonly => [qw/all/],
+	make_readonly_ref => [qw/all/],
 	unmake_readonly => [qw/all/],
 	is_readonly => [qw/all/],
 );
@@ -29,7 +30,7 @@ Const::XS - Facility for creating read-only scalars, arrays, hashes
 
 =head1 VERSION
 
-Version 0.15
+Version 0.16
 
 =cut
 
@@ -68,7 +69,7 @@ Version 0.15
 
 =head2 const
 
-This is the one of four functions of this module. It takes a scalar, array or hash lvalue as the first argument, and a list of one or more values depending on the type of the first argument as the value for the variable. It will set the variable to that value and subsequently make it readonly. Arrays and hashes will be made deeply readonly.
+This is the one of five functions of this module. It takes a scalar, array or hash lvalue as the first argument, and a list of one or more values depending on the type of the first argument as the value for the variable. It will set the variable to that value and subsequently make it readonly. Arrays and hashes will be made deeply readonly.
 
 	const my %factory => (
 		workers => 5,
@@ -83,18 +84,20 @@ This is the one of four functions of this module. It takes a scalar, array or ha
 
 =head2 make_readonly
 
-The second function exported by this module is make_readonly. It will take a perl variable or reference and make it readonly. 
+The second function exported by this module is make_readonly. It will take a perl variable and deeply make it readonly. 
 
 	my $string = "abc";
 	make_readonly($string);
 	$string = 'def'; # errors
 
-	my $ref = { a => 1, b => 2, c => 3 };
-	make_readonly($ref);
-	$ref->{d}; # errors
-	$ref = { new => 1 }; # errors 
+	my %hash = ( a => 1, b => 2, c => 3 );
+	make_readonly(%hash);
+	$hash{d}; # errors
+	%hash = ( new => 1 ); # errors 
 
-Please note that if you call make_readonly on struct directly it will make that struct readonly however it is 'copied' into the variable and that does not get set as readonly. Take the following example.
+=head2 make_readonly_ref
+
+The third function exported by this module is make_readonly_ref. It will take a perl struct and deeply make it readonly. Please note that if you call make_readonly_ref the struct will be deeply made readonly however it is 'copied' into the variable and that does not get set as readonly. Take the following example.
 
 	my $ref = make_readonly({a => 1, b => 2, c => 3 }; # we copy into $ref
 	$ref->{d}; # errors
@@ -102,7 +105,7 @@ Please note that if you call make_readonly on struct directly it will make that
 
 =head2 unmake_readonly
 
-The third function exported by this module is unmake_readonly. It will take a perl variable that has been through make_readonly and deeply make it writeable again.
+The fourth function exported by this module is unmake_readonly. It will take a perl variable that has been through make_readonly/make_readonly_ref and deeply make it writeable again.
 
 	my $string = "abc";
 	make_readonly($string);
@@ -112,12 +115,12 @@ The third function exported by this module is unmake_readonly. It will take a pe
 
 =head2 is_readonly
 
-The fourth function exported by this module is is_readonly. It will deeply check a reference to see if it is readonly.
+The fifth function exported by this module is is_readonly. It will deeply check a variable to see if it is readonly.
 
-	my $ref = { one => "abc" };
-	is_readonly($ref); # 0;
-	make_readonly($ref);
-	is_readonly($ref); # 1;
+	my %hash = ( one => "abc" );
+	is_readonly(%hash); # 0;
+	make_readonly(%hash);
+	is_readonly(%hash); # 1;
 	
 =head2 BENCHMARK
 
